==> OneHitWonder_4211_v0.034.zip: Interface/AddOns/OneHitWonder/localization_Class_Rogue.lua <==
-- Rogue options

ONEHITWONDER_ROGUE_SEPARATOR								= "Rogue Section";
ONEHITWONDER_ROGUE_SEPARATOR_INFO							= "Contains settings for the Rogue";

ONEHITWONDER_ROGUE_USE_PICK_POCKET							= "Use Pickpocket";
ONEHITWONDER_ROGUE_USE_PICK_POCKET_INFO						= "Whether OneHitWonder should pickpocket mobs.";

ONEHITWONDER_ROGUE_USE_RIPOSTE								= "Use Riposte";
ONEHITWONDER_ROGUE_USE_RIPOSTE_INFO							= "Whether OHW should use Riposte on mobs at all (some mobs are always skipped).";

ONEHITWONDER_ROGUE_USE_SMART_RUPTURE						= "Use Smart Rupture";
ONEHITWONDER_ROGUE_USE_SMART_RUPTURE_INFO					= "Whether OHW should use Rupture on mobs at all (some mobs should be skipped).";

ONEHITWONDER_ROGUE_USE_GHOSTLY_STRIKE						= "Use Ghostly Strike";
ONEHITWONDER_ROGUE_USE_GHOSTLY_STRIKE_INFO					= "Whether OHW should use Ghostly Strike when available.";

ONEHITWONDER_ROGUE_USE_DETECT_TRAPS							= "Keep up Detect Traps";
ONEHITWONDER_ROGUE_USE_DETECT_TRAPS_INFO					= "Keep up Detect Traps";

ONEHITWONDER_ROGUE_REACTIVE_CAST_KICK						= "Use Kick reactively";
ONEHITWONDER_ROGUE_REACTIVE_CAST_KICK_INFO					= "Allows OHW to use Kick to interrupt casters.";

ONEHITWONDER_ROGUE_REACTIVE_CAST_KIDNEY_SHOT				= "Use Kidney Shot reactively";
ONEHITWONDER_ROGUE_REACTIVE_CAST_KIDNEY_SHOT_INFO			= "Allows OHW to use Kidney Shot to interrupt casters. KS will only be used if Kick is unavailable/not used for reactive stuff.";

ONEHITWONDER_ROGUE_REACTIVE_CAST_GOUGE						= "Use Gouge reactively";
ONEHITWONDER_ROGUE_REACTIVE_CAST_GOUGE_INFO					= "Allows OHW to use Gouge to interrupt casters. Gouge will only be used if Kick/Kidney Shot is unavailable/not used for reactive stuff.";

ONEHITWONDER_ROGUE_STEALTH_ATTACK_SEPARATOR					= "Stealth Attack";
ONEHITWONDER_ROGUE_STEALTH_ATTACK_SEPARATOR_INFO			= "Contains settings for the Rogue Stealth Attack";

ONEHITWONDER_ROGUE_ALLOWED_STEALTH_ATTACK_ATTEMPTS			= "Number of allowed attempts";
ONEHITWONDER_ROGUE_ALLOWED_STEALTH_ATTACK_ATTEMPTS_INFO		= "The number of possible attempts to stealth attack a target that are allowed to be made. 0 means infinite.";
ONEHITWONDER_ROGUE_ALLOWED_STEALTH_ATTACK_ATTEMPTS_APPEND	= " attempts";


ONEHITWONDER_ROGUE_STEALTH_OPENER_CHOICE					= "Stealth opener";
ONEHITWONDER_ROGUE_STEALTH_OPENER_CHOICE_INFO				= "The stealth opener to use. 0 = none.";
ONEHITWONDER_ROGUE_STEALTH_OPENER_CHOICE_APPEND				= "";

ONEHITWONDER_ROGUE_STEALTH_OPENER_BACKUP_CHOICE				= "Stealth opener (backup)";



ONEHITWONDER_ROGUE_USE_GARROTE								= "Use Garrote";
ONEHITWONDER_ROGUE_USE_GARROTE_INFO							= "Whether OneHitWonder should use Garrote as a stealth-opener.";

ONEHITWONDER_ROGUE_USE_CHEAP_SHOT							= "Use Cheap Shot";
ONEHITWONDER_ROGUE_USE_CHEAP_SHOT_INFO						= "Whether OneHitWonder should use Cheap Shot as a stealth-opener.";

ONEHITWONDER_ROGUE_USE_AMBUSH								= "Use Ambush";
ONEHITWONDER_ROGUE_USE_AMBUSH_INFO							= "Whether OneHitWonder should use Ambush as a stealth-opener.";

ONEHITWONDER_ROGUE_USE_BACKSTAB								= "Use Backstab";
ONEHITWONDER_ROGUE_USE_BACKSTAB_INFO						= "Whether OneHitWonder should use Backstab as a stealth-opener.";

ONEHITWONDER_ROGUE_EXPOSE_ARMOR_SEPARATOR					= "Expose Armor";
ONEHITWONDER_ROGUE_EXPOSE_ARMOR_SEPARATOR_INFO				= "Contains settings for the Rogue Expose Armor ability";

ONEHITWONDER_ROGUE_USE_SMART_EXPOSE_ARMOR					= "Use smart Expose Armor";
ONEHITWONDER_ROGUE_USE_SMART_EXPOSE_ARMOR_INFO				= "Will apply Expose Armor to non-cloth-wearing entities (hopefully).";

ONEHITWONDER_ROGUE_EXPOSE_ARMOR								= "Prevent Expose Armor at % health";
ONEHITWONDER_ROGUE_EXPOSE_ARMOR_INFO						= "Determines when OneHitWonder should stop trying to apply Expose Armor depending on target health.";
ONEHITWONDER_ROGUE_EXPOSE_ARMOR_APPEND						= "%";

ONEHITWONDER_ROGUE_EXPOSE_ARMOR_COMBO_POINTS_MIN			= "Expose Armor combo points min";
ONEHITWONDER_ROGUE_EXPOSE_ARMOR_COMBO_POINTS_MIN_INFO		= "Will not Expose Armor if you have not accumulated at least this many Combo Points";
ONEHITWONDER_ROGUE_EXPOSE_ARMOR_COMBO_POINTS_MIN_APPEND		= " CP";

ONEHITWONDER_ROGUE_EXPOSE_ARMOR_COMBO_POINTS_MAX			= "Expose Armor combo points max";
ONEHITWONDER_ROGUE_EXPOSE_ARMOR_COMBO_POINTS_MAX_INFO		= "Will not Expose Armor when you have accumulated more than this number of Combo Points";
ONEHITWONDER_ROGUE_EXPOSE_ARMOR_COMBO_POINTS_MAX_APPEND		= " CP";

ONEHITWONDER_ROGUE_SLICE_DICE_SEPARATOR						= "Slice & Dice";
ONEHITWONDER_ROGUE_SLICE_DICE_SEPARATOR_INFO				= "Contains settings for the Rogue Slice & Dice ability";

ONEHITWONDER_ROGUE_USE_SMART_SLICE_DICE						= "Use smart Slice & Dice";
ONEHITWONDER_ROGUE_USE_SMART_SLICE_DICE_INFO				= "Will use Slice & Dice when \"necessary\".";

ONEHITWONDER_ROGUE_SLICE_DICE								= "Do Slice&Dice at % health";
ONEHITWONDER_ROGUE_SLICE_DICE_INFO							= "When should OHW stop/start trying to get Slice&Dice depending on target health.(checked = stop, unchecked=start)";
ONEHITWONDER_ROGUE_SLICE_DICE_APPEND						= "%";

ONEHITWONDER_ROGUE_SLICE_DICE_COMBO_POINTS_MIN				= "Slice&Dice combo points min";
ONEHITWONDER_ROGUE_SLICE_DICE_COMBO_POINTS_MIN_INFO			= "Will not Slice&Dice if you have not accumulated at least this many Combo Points";
ONEHITWONDER_ROGUE_SLICE_DICE_COMBO_POINTS_MIN_APPEND		= " CP";

ONEHITWONDER_ROGUE_SLICE_DICE_COMBO_POINTS_MAX				= "Slice&Dice combo points max";
ONEHITWONDER_ROGUE_SLICE_DICE_COMBO_POINTS_MAX_INFO			= "Will not Slice&Dice when you have accumulated more than this number of Combo Points";
ONEHITWONDER_ROGUE_SLICE_DICE_COMBO_POINTS_MAX_APPEND		= " CP";

ONEHITWONDER_ROGUE_EVISCERATE_SEPARATOR						= "Eviscerate";
ONEHITWONDER_ROGUE_EVISCERATE_SEPARATOR_INFO				= "Contains settings for the Rogue Eviscerate ability";

ONEHITWONDER_ROGUE_EVISCERATE_USE_NEW						= "Use user-settings for Eviscerate";
ONEHITWONDER_ROGUE_EVISCERATE_USE_NEW_INFO					= "By default, a complex and arcane (yet subtly balanced) formula is used to calculate when Eviscerate should be done. Check this to enable the user settings.";

ONEHITWONDER_ROGUE_EVISCERATE_NOW							= "When to do 1 CP Eviscerates";
ONEHITWONDER_ROGUE_EVISCERATE_NOW_INFO						= "At a certain point, getting more combo points is no longer necesary. This setting regulates when OHW decides that this is so.";
ONEHITWONDER_ROGUE_EVISCERATE_NOW_APPEND					= "%";

ONEHITWONDER_ROGUE_EVISCERATE_EXTRA_COMBO_POINT				= "When to require one more CP";
ONEHITWONDER_ROGUE_EVISCERATE_EXTRA_COMBO_POINT_INFO		= "Healthy targets need higher-CP Eviscerates to really feel pain. Cut-off point for +1 CP from the base.";
ONEHITWONDER_ROGUE_EVISCERATE_EXTRA_COMBO_POINT_APPEND		= "%";

ONEHITWONDER_ROGUE_EVISCERATE_EXTRA_COMBO_POINTS			= "When to require two more CPs";
ONEHITWONDER_ROGUE_EVISCERATE_EXTRA_COMBO_POINTS_INFO		= "Disgustingly healthy targets? Set the limit of this cut-off at which to aim for +2 CPs from the base.";
ONEHITWONDER_ROGUE_EVISCERATE_EXTRA_COMBO_POINTS_APPEND		= "%";

ONEHITWONDER_ROGUE_EVISCERATE_BASE_COMBO_POINTS				= "How many CPs to aim for";
ONEHITWONDER_ROGUE_EVISCERATE_BASE_COMBO_POINTS_INFO		= "This settings regulates how many CPs a normal Eviscerate should have before it is executed.";
ONEHITWONDER_ROGUE_EVISCERATE_BASE_COMBO_POINTS_APPEND		= " CP";

ONEHITWONDER_ROGUE_COLD_BLOOD_SEPARATOR						= "Cold Blood";
ONEHITWONDER_ROGUE_COLD_BLOOD_SEPARATOR_INFO				= "Contains settings for Cold Blood";

ONEHITWONDER_ROGUE_USE_COLD_BLOOD							= "Use Cold Blood";
ONEHITWONDER_ROGUE_USE_COLD_BLOOD_INFO						= "Allows the use of Cold Blood when Eviscerating with high number of Combo Points.";

ONEHITWONDER_ROGUE_COLD_BLOOD_ONLY_IN_PVP					= "Only use Cold Blood in PvP";
ONEHITWONDER_ROGUE_COLD_BLOOD_ONLY_IN_PVP_INFO				= "Does not allow Cold Blood to be used unless you are PvP flagged.";

ONEHITWONDER_ROGUE_COLD_BLOOD_COMBO_POINTS_MIN				= "Cold Blood combo points min";
ONEHITWONDER_ROGUE_COLD_BLOOD_COMBO_POINTS_MIN_INFO			= "Will not use Cold Blood if you have not accumulated at least this many Combo Points";
ONEHITWONDER_ROGUE_COLD_BLOOD_COMBO_POINTS_MIN_APPEND		= " CP";



if ( GetLocale() == "frFR" ) then
elseif ( GetLocale() == "deDE" ) then
end

==> OneHitWonder_4211_v0.036.zip: Interface/AddOns/OneHitWonder/localization_Class_Rogue.lua <==
-- Rogue options

ONEHITWONDER_ROGUE_SEPARATOR								= "Rogue Section";
ONEHITWONDER_ROGUE_SEPARATOR_INFO							= "Contains settings for the Rogue";

ONEHITWONDER_ROGUE_USE_PICK_POCKET							= "Use Pickpocket";
ONEHITWONDER_ROGUE_USE_PICK_POCKET_INFO						= "Whether OneHitWonder should pickpocket mobs.";

ONEHITWONDER_ROGUE_USE_RIPOSTE								= "Use Riposte";
ONEHITWONDER_ROGUE_USE_RIPOSTE_INFO							= "Whether OHW should use Riposte on mobs at all (some mobs are always skipped).";

ONEHITWONDER_ROGUE_USE_SMART_RUPTURE						= "Use Smart Rupture";
ONEHITWONDER_ROGUE_USE_SMART_RUPTURE_INFO					= "Whether OHW should use Rupture on mobs at all (some mobs should be skipped).";

ONEHITWONDER_ROGUE_USE_DETECT_TRAPS							= "Keep up Detect Traps";
ONEHITWONDER_ROGUE_USE_DETECT_TRAPS_INFO					= "Keep up Detect Traps";

ONEHITWONDER_ROGUE_REACTIVE_CAST_KICK						= "Use Kick reactively";
ONEHITWONDER_ROGUE_REACTIVE_CAST_KICK_INFO					= "Allows OHW to use Kick to interrupt casters.";

ONEHITWONDER_ROGUE_REACTIVE_CAST_KIDNEY_SHOT				= "Use Kidney Shot reactively";
ONEHITWONDER_ROGUE_REACTIVE_CAST_KIDNEY_SHOT_INFO			= "Allows OHW to use Kidney Shot to interrupt casters. KS will only be used if Kick is unavailable/not used for reactive stuff.";

ONEHITWONDER_ROGUE_REACTIVE_CAST_GOUGE						= "Use Gouge reactively";
ONEHITWONDER_ROGUE_REACTIVE_CAST_GOUGE_INFO					= "Allows OHW to use Gouge to interrupt casters. Gouge will only be used if Kick/Kidney Shot is unavailable/not used for reactive stuff.";

ONEHITWONDER_ROGUE_USE_GHOSTLY_STRIKE						= "Use Ghostly Strike";
ONEHITWONDER_ROGUE_USE_GHOSTLY_STRIKE_INFO					= "Whether OHW should use Ghostly Strike.";

ONEHITWONDER_ROGUE_GHOSTLY_STRIKE_HEALTH					= "Do Ghostly Strike at % health";
ONEHITWONDER_ROGUE_GHOSTLY_STRIKE_HEALTH_INFO				= "When should OHW stop/start trying to use Ghostly Strike depending on target health.(checked = stop, unchecked=start)";
ONEHITWONDER_ROGUE_GHOSTLY_STRIKE_HEALTH_APPEND				= "%";



ONEHITWONDER_ROGUE_STEALTH_ATTACK_SEPARATOR					= "Stealth Attack";
ONEHITWONDER_ROGUE_STEALTH_ATTACK_SEPARATOR_INFO			= "Contains settings for the Rogue Stealth Attack";

ONEHITWONDER_ROGUE_ALLOWED_STEALTH_ATTACK_ATTEMPTS			= "Number of allowed attempts";
ONEHITWONDER_ROGUE_ALLOWED_STEALTH_ATTACK_ATTEMPTS_INFO		= "The number of possible attempts to stealth attack a target that are allowed to be made. 0 means infinite.";
ONEHITWONDER_ROGUE_ALLOWED_STEALTH_ATTACK_ATTEMPTS_APPEND	= " attempts";


ONEHITWONDER_ROGUE_STEALTH_OPENER_CHOICE					= "Stealth opener";
ONEHITWONDER_ROGUE_STEALTH_OPENER_CHOICE_INFO				= "The stealth opener to use. 0 = none.";
ONEHITWONDER_ROGUE_STEALTH_OPENER_CHOICE_APPEND				= "";

ONEHITWONDER_ROGUE_STEALTH_OPENER_BACKUP_CHOICE				= "Stealth opener (backup)";



ONEHITWONDER_ROGUE_USE_GARROTE								= "Use Garrote";
ONEHITWONDER_ROGUE_USE_GARROTE_INFO							= "Whether OneHitWonder should use Garrote as a stealth-opener.";

ONEHITWONDER_ROGUE_USE_CHEAP_SHOT							= "Use Cheap Shot";
ONEHITWONDER_ROGUE_USE_CHEAP_SHOT_INFO						= "Whether OneHitWonder should use Cheap Shot as a stealth-opener.";

ONEHITWONDER_ROGUE_USE_AMBUSH								= "Use Ambush";
ONEHITWONDER_ROGUE_USE_AMBUSH_INFO							= "Whether OneHitWonder should use Ambush as a stealth-opener.";

ONEHITWONDER_ROGUE_USE_BACKSTAB								= "Use Backstab";
ONEHITWONDER_ROGUE_USE_BACKSTAB_INFO						= "Whether OneHitWonder should use Backstab as a stealth-opener.";

ONEHITWONDER_ROGUE_EXPOSE_ARMOR_SEPARATOR					= "Expose Armor";
ONEHITWONDER_ROGUE_EXPOSE_ARMOR_SEPARATOR_INFO				= "Contains settings for the Rogue Expose Armor ability";

ONEHITWONDER_ROGUE_USE_SMART_EXPOSE_ARMOR					= "Use smart Expose Armor";
ONEHITWONDER_ROGUE_USE_SMART_EXPOSE_ARMOR_INFO				= "Will apply Expose Armor to non-cloth-wearing entities (hopefully).";

ONEHITWONDER_ROGUE_EXPOSE_ARMOR								= "Prevent Expose Armor at % health";
ONEHITWONDER_ROGUE_EXPOSE_ARMOR_INFO						= "Determines when OneHitWonder should stop trying to apply Expose Armor depending on target health.";
ONEHITWONDER_ROGUE_EXPOSE_ARMOR_APPEND						= "%";

ONEHITWONDER_ROGUE_EXPOSE_ARMOR_COMBO_POINTS_MIN			= "Expose Armor combo points min";
ONEHITWONDER_ROGUE_EXPOSE_ARMOR_COMBO_POINTS_MIN_INFO		= "Will not Expose Armor if you have not accumulated at least this many Combo Points";
ONEHITWONDER_ROGUE_EXPOSE_ARMOR_COMBO_POINTS_MIN_APPEND		= " CP";

ONEHITWONDER_ROGUE_EXPOSE_ARMOR_COMBO_POINTS_MAX			= "Expose Armor combo points max";
ONEHITWONDER_ROGUE_EXPOSE_ARMOR_COMBO_POINTS_MAX_INFO		= "Will not Expose Armor when you have accumulated more than this number of Combo Points";
ONEHITWONDER_ROGUE_EXPOSE_ARMOR_COMBO_POINTS_MAX_APPEND		= " CP";

ONEHITWONDER_ROGUE_SLICE_DICE_SEPARATOR						= "Slice & Dice";
ONEHITWONDER_ROGUE_SLICE_DICE_SEPARATOR_INFO				= "Contains settings for the Rogue Slice & Dice ability";

ONEHITWONDER_ROGUE_USE_SMART_SLICE_DICE						= "Use smart Slice & Dice";
ONEHITWONDER_ROGUE_USE_SMART_SLICE_DICE_INFO				= "Will use Slice & Dice when \"necessary\".";

ONEHITWONDER_ROGUE_SLICE_DICE								= "Do Slice&Dice at % health";
ONEHITWONDER_ROGUE_SLICE_DICE_INFO							= "When should OHW stop/start trying to get Slice&Dice depending on target health.(checked = stop, unchecked=start)";
ONEHITWONDER_ROGUE_SLICE_DICE_APPEND						= "%";

ONEHITWONDER_ROGUE_SLICE_DICE_COMBO_POINTS_MIN				= "Slice&Dice combo points min";
ONEHITWONDER_ROGUE_SLICE_DICE_COMBO_POINTS_MIN_INFO			= "Will not Slice&Dice if you have not accumulated at least this many Combo Points";
ONEHITWONDER_ROGUE_SLICE_DICE_COMBO_POINTS_MIN_APPEND		= " CP";

ONEHITWONDER_ROGUE_SLICE_DICE_COMBO_POINTS_MAX				= "Slice&Dice combo points max";
ONEHITWONDER_ROGUE_SLICE_DICE_COMBO_POINTS_MAX_INFO			= "Will not Slice&Dice when you have accumulated more than this number of Combo Points";
ONEHITWONDER_ROGUE_SLICE_DICE_COMBO_POINTS_MAX_APPEND		= " CP";

ONEHITWONDER_ROGUE_EVISCERATE_SEPARATOR						= "Eviscerate";
ONEHITWONDER_ROGUE_EVISCERATE_SEPARATOR_INFO				= "Contains settings for the Rogue Eviscerate ability";

ONEHITWONDER_ROGUE_EVISCERATE_USE_NEW						= "Use user-settings for Eviscerate";
ONEHITWONDER_ROGUE_EVISCERATE_USE_NEW_INFO					= "By default, a complex and arcane (yet subtly balanced) formula is used to calculate when Eviscerate should be done. Check this to enable the user settings.";

ONEHITWONDER_ROGUE_EVISCERATE_NOW							= "When to do 1 CP Eviscerates";
ONEHITWONDER_ROGUE_EVISCERATE_NOW_INFO						= "At a certain point, getting more combo points is no longer necesary. This setting regulates when OHW decides that this is so.";
ONEHITWONDER_ROGUE_EVISCERATE_NOW_APPEND					= "%";

ONEHITWONDER_ROGUE_EVISCERATE_EXTRA_COMBO_POINT				= "When to require one more CP";
ONEHITWONDER_ROGUE_EVISCERATE_EXTRA_COMBO_POINT_INFO		= "Healthy targets need higher-CP Eviscerates to really feel pain. Cut-off point for +1 CP from the base.";
ONEHITWONDER_ROGUE_EVISCERATE_EXTRA_COMBO_POINT_APPEND		= "%";

ONEHITWONDER_ROGUE_EVISCERATE_EXTRA_COMBO_POINTS			= "When to require two more CPs";
ONEHITWONDER_ROGUE_EVISCERATE_EXTRA_COMBO_POINTS_INFO		= "Disgustingly healthy targets? Set the limit of this cut-off at which to aim for +2 CPs from the base.";
ONEHITWONDER_ROGUE_EVISCERATE_EXTRA_COMBO_POINTS_APPEND		= "%";

ONEHITWONDER_ROGUE_EVISCERATE_BASE_COMBO_POINTS				= "How many CPs to aim for";
ONEHITWONDER_ROGUE_EVISCERATE_BASE_COMBO_POINTS_INFO		= "This settings regulates how many CPs a normal Eviscerate should have before it is executed.";
ONEHITWONDER_ROGUE_EVISCERATE_BASE_COMBO_POINTS_APPEND		= " CP";

ONEHITWONDER_ROGUE_COLD_BLOOD_SEPARATOR						= "Cold Blood";
ONEHITWONDER_ROGUE_COLD_BLOOD_SEPARATOR_INFO				= "Contains settings for Cold Blood";

ONEHITWONDER_ROGUE_USE_COLD_BLOOD							= "Use Cold Blood";
ONEHITWONDER_ROGUE_USE_COLD_BLOOD_INFO						= "Allows the use of Cold Blood when Eviscerating with high number of Combo Points.";

ONEHITWONDER_ROGUE_COLD_BLOOD_ONLY_IN_PVP					= "Only use Cold Blood in PvP";
ONEHITWONDER_ROGUE_COLD_BLOOD_ONLY_IN_PVP_INFO				= "Does not allow Cold Blood to be used unless you are PvP flagged.";

ONEHITWONDER_ROGUE_COLD_BLOOD_COMBO_POINTS_MIN				= "Cold Blood combo points min";
ONEHITWONDER_ROGUE_COLD_BLOOD_COMBO_POINTS_MIN_INFO			= "Will not use Cold Blood if you have not accumulated at least this many Combo Points";
ONEHITWONDER_ROGUE_COLD_BLOOD_COMBO_POINTS_MIN_APPEND		= " CP";



if ( GetLocale() == "frFR" ) then
elseif ( GetLocale() == "deDE" ) then
end
